* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation)
  * Phase 3. Explore: Define the To-Be Architecture
